@@ -1,2 +1,2 @@
 ?package(opentyrian):needs="X11|text|vc|wm" section="Apps/see-menu-manual"\
-  title="opentyrian" command="/usr/bin/opentyrian"
+  title="opentyrian" command="/usr/bin/tyrian"
